@@ -8,7 +8,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	admissionregclient "k8s.io/client-go/kubernetes/typed/admissionregistration/v1"
 	admissionreglister "k8s.io/client-go/listers/admissionregistration/v1"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 
 	"github.com/openshift/service-ca-operator/pkg/controller/api"
 )
